package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CygxChartCollect struct {
	Id          int       `orm:"column(id);pk"`
	ChartId     int       `description:"图表ID"`
	UserId      int       `description:"用户ID"`
	CreateTime  time.Time `description:"创建时间"`
	Mobile      string    `description:"手机号"`
	Email       string    `description:"邮箱"`
	CompanyId   int       `description:"公司id"`
	CompanyName string    `description:"公司名称"`
	RealName    string    `description:"用户实际名称"`
	SellerName  string    `description:"所属销售"`
}

//添加收藏信息
func AddCygxChartCollect(item *CygxChartCollect) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

type ChartCollectResp struct {
	Status       int `description:"1:收藏，2：取消收藏"`
	CollectCount int `description:"收藏总数"`
}

func RemoveChartCollect(userId, ChartId int) (err error) {
	o := orm.NewOrm()
	sql := `DELETE FROM cygx_chart_collect WHERE user_id=? AND chart_id=? `
	_, err = o.Raw(sql, userId, ChartId).Exec()
	return
}

func GetChartCountByUserId(userId, chartID int) (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM cygx_chart_collect WHERE user_id=? AND chart_id=? `
	err = orm.NewOrm().Raw(sql, userId, chartID).QueryRow(&count)
	return
}

func GetChartCountByUser(userId int) (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM cygx_chart_collect WHERE user_id=?  `
	err = orm.NewOrm().Raw(sql, userId).QueryRow(&count)
	return
}

type CygxChartTop struct {
	Id          int       `orm:"column(id);pk"`
	ChartId     int       `description:"图表ID"`
	UserId      int       `description:"用户ID"`
	CreateTime  time.Time `description:"创建时间"`
	Mobile      string    `description:"手机号"`
	Email       string    `description:"邮箱"`
	CompanyId   int       `description:"公司id"`
	CompanyName string    `description:"公司名称"`
	RealName    string    `description:"用户实际名称"`
	SellerName  string    `description:"所属销售"`
}

//添加置顶信息
func AddCygxChartTop(item *CygxChartTop) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

type ChartTopresp struct {
	Status       int `description:"1:收藏，2：取消收藏"`
	CollectCount int `description:"收藏总数"`
}

func RemoveChartTop(userId, ChartId int) (err error) {
	o := orm.NewOrm()
	sql := `DELETE FROM cygx_chart_top WHERE user_id=? AND chart_id=? `
	_, err = o.Raw(sql, userId, ChartId).Exec()
	return
}

func GetChartTopCountByUserId(userId, chartID int) (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM cygx_chart_top WHERE user_id=? AND chart_id=? `
	err = orm.NewOrm().Raw(sql, userId, chartID).QueryRow(&count)
	return
}
